/* eslint-disable import/prefer-default-export */
import WebvizPluginPlaceholder from "./components/WebvizPluginPlaceholder.react";
import ColorScales from "./components/ColorScales.react";
import Select from "./components/Select.react";

import "./flexbox.css"

export { WebvizPluginPlaceholder, ColorScales, Select };
